@@ -8,24 +8,22 @@
 ###############################################################################
 
 """
-FILE:  Editra.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
+This module defines the Editra Application object and the Main method for
+running Editra.
 
-SUMMARY:
-This module defines the Editra Application object and the Main method
-for running Editra.
+@summary: Editra's main application object and MainLoop
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 52302 2008-03-04 08:04:48Z CJP $"
-__revision__ = "$Revision: 52302 $"
+__svnid__ = "$Id: Editra.py 53095 2008-04-09 01:39:09Z CJP $"
+__revision__ = "$Revision: 53095 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
 import os
 import sys
+import locale
 import time
 import getopt
 import wx
@@ -68,7 +66,7 @@ _ = wx.GetTranslation
 
 class Editra(wx.App, events.AppEventHandlerMixin):
     """The Editra Application Object
-    @see: L{wx.App}
+    @deprecated: L{GetMainWindow}
 
     """
     def __init__(self, *args, **kargs):
@@ -85,6 +83,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         self._windows = dict()
 
         # Setup Locale
+        locale.setlocale(locale.LC_ALL, '')
         self.locale = wx.Locale(ed_i18n.GetLangId(profiler.Profile_Get('LANG')))
         if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
             self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
@@ -357,7 +356,7 @@ class Editra(wx.App, events.AppEventHandlerMixin):
 
     def OnNotify(self, evt):
         """Handle notification events
-        @param evt: L{ed_event.NotifyEvent}
+        @param evt: L{ed_event.NotificationEvent}
 
         """
         e_val = evt.GetValue()
@@ -595,8 +594,12 @@ def Main():
                                  wx.SPLASH_NO_TIMEOUT, 0, None, wx.ID_ANY)
         splash.Show()
 
-    frame = ed_main.MainWindow(None, wx.ID_ANY, profiler.Profile_Get('WSIZE'),
-                               ed_glob.PROG_NAME)
+    if profiler.Profile_Get('SET_WSIZE'):
+        wsize = profiler.Profile_Get('WSIZE')
+    else:
+        wsize = (700, 450)
+    frame = ed_main.MainWindow(None, wx.ID_ANY, wsize, ed_glob.PROG_NAME)
+    frame.Maximize(profiler.Profile_Get('MAXIMIZED'))
     editra_app.RegisterWindow(repr(frame), frame, True)
     editra_app.SetTopWindow(frame)
     frame.Show(True)
