@@ -18,41 +18,41 @@ the details and thread safety of the gui.
 For example usage of these classes see ed_log and the Editra's Launch plugin
 
 Class OutputBuffer:
-  This is the main class exported by ths module. It provides a readonly output
+This is the main class exported by ths module. It provides a readonly output
 display buffer that when used with the other classes in this module provides an
 easy way to display continous output from other processes and threads. It 
 provides two methods for subclasses to override if they wish to perform custom 
 handling.
 
-  * Override the ApplyStyles method to do any processing and coloring of the
+  - Override the ApplyStyles method to do any processing and coloring of the
     text as it is put in the buffer.
-  * Override the DoHotSpotClicked method to handle any actions to take when a
+  - Override the DoHotSpotClicked method to handle any actions to take when a
     hotspot has been clicked in the buffer.
-  * Override the DoUpdatesEmpty method to perform any idle processing when no
+  - Override the DoUpdatesEmpty method to perform any idle processing when no
     new text is waiting to be processed.
 
 Class ProcessBufferMixin:
-  Mixin class for the L{OutputBuffer} class that provides handling for when an
+Mixin class for the L{OutputBuffer} class that provides handling for when an
 OutputBuffer is used with a L{ProcessThread}. It provides three methods that can
 be overridden in subclasses to perform extra processing.
 
-  * DoProcessStart: Called as the process is being started in the ProcessThread,
+  - DoProcessStart: Called as the process is being started in the ProcessThread,
                     it recieves the process command string as an argument.
-  * DoFilterInput: Called as each chunk of output comes from the running process
+  - DoFilterInput: Called as each chunk of output comes from the running process
                    use it to filter the results before displaying them in the
                    buffer.
-  * DoProcessExit: Called when the running process has exited. It recieves the
+  - DoProcessExit: Called when the running process has exited. It recieves the
                    processes exit code as a parameter.
 
 Class ProcessThread:
-  Thread class for running subprocesses and posting the output to an 
+Thread class for running subprocesses and posting the output to an 
 L{OutputBuffer} via events.
        
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: outbuff.py 52287 2008-03-03 14:12:20Z CJP $"
-__revision__ = "$Revision: 52287 $"
+__svnid__ = "$Id: outbuff.py 52850 2008-03-27 12:51:51Z CJP $"
+__revision__ = "$Revision: 52850 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -366,8 +366,8 @@ class ProcessBufferMixin:
 
     def DoProcessExit(self, code=0):
         """Override this method to do any post processing after the running
-        task has exited. Typically this is a good place to call L{Stop} to
-        stop the buffers timer.
+        task has exited. Typically this is a good place to call 
+        L{OutputBuffer.Stop} to stop the buffers timer.
         @keyword code: Exit code of program
 
         """
@@ -401,6 +401,11 @@ class ProcessThread(threading.Thread):
     def __init__(self, parent, command, fname='',
                  args=list(), cwd=None, env=None):
         """Initialize the ProcessThread object
+        Example:
+          >>> myproc = ProcessThread(myframe, '/usr/local/bin/python',
+                                     'hello.py', '--version', '/Users/me/home/')
+          >>> myproc.start()
+
         @param parent: Parent Window/EventHandler to recieve the events
                        generated by the process.
         @param command: Command string to execute as a subprocess.
@@ -409,10 +414,6 @@ class ProcessThread(threading.Thread):
         @keyword cwd: Directory to execute process from or None to use current
         @keyword env: Environment to run the process in (dictionary) or None to
                       use default.
-        @example:
-            myproc = ProcessThread(myframe, '/usr/local/bin/python', 'hello.py',
-                                   '--version', '/Users/me/home/')
-            myproc.start()
 
         """
         threading.Thread.__init__(self)
@@ -545,8 +546,8 @@ class ProcessThread(threading.Thread):
         self._cmd['cmd'] = cmd
 
     def SetFilename(self, fname):
-        """Set the command to execute
-        @param cmd: Command string
+        """Set the filename to run the command on
+        @param fname: string or unicode
 
         """
         self._cmd['file'] = fname
