@@ -3,31 +3,24 @@
 # Purpose: Global IDs/objects used throughout Editra                          #
 # Author: Cody Precord <cprecord@editra.org>                                  #
 # Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: ed_glob.py                                                         #
-# @author: Cody Precord                                                    #
-#                                                                          #
-# @summary:                                                                #
-#   This file contains variables that are or may be used in multiple       #
-#   files and libraries within the project. Its pupose is to create a      #
-#   globally accessable access point for all common variables in the       #
-#   project.                                                               #
-#                                                                          #
-#--------------------------------------------------------------------------#
+This file contains variables that are or may be used in multiple files and
+libraries within the project. Its pupose is to create a globally accessable
+access point for all common variables in the project.
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_glob.py 52188 2008-02-29 06:19:49Z CJP $"
-__revision__ = "$Revision: 52188 $"
+__svnid__ = "$Id: ed_glob.py 53301 2008-04-22 03:37:58Z CJP $"
+__revision__ = "$Revision: 53301 $"
 
-__all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN', 
-            'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL', 
-            'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE', 'ID_PRINT', 'ID_PRINT_PRE', 
-            'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 'ID_REDO', 'ID_CUT', 
+__all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
+            'ID_CLOSE', 'ID_CLOSEALL', 'ID_SAVE', 'ID_SAVEAS', 'ID_SAVEALL',
+            'ID_SAVE_PROFILE', 'ID_LOAD_PROFILE', 'ID_PRINT', 'ID_PRINT_PRE',
+            'ID_PRINT_SU', 'ID_EXIT', 'ID_UNDO', 'ID_REDO', 'ID_CUT',
             'ID_COPY', 'ID_PASTE', 'ID_SELECTALL', 'ID_ADD_BM', 'ID_DEL_BM',
             'ID_DEL_ALL_BM', 'ID_LINE_AFTER', 'ID_LINE_BEFORE', 'ID_CUT_LINE',
             'ID_COPY_LINE', 'ID_JOIN_LINES', 'ID_TRANSPOSE', 'ID_FIND',
@@ -45,7 +38,7 @@ __all__ = [ 'CONFIG', 'SB_INFO', 'VERSION', 'PROG_NAME', 'ID_NEW', 'ID_OPEN',
             'ID_MACRO_PLAY', 'ID_ABOUT', 'ID_HOMEPAGE', 'ID_CONTACT',
             'ID_COMMAND_BAR', 'ID_DOCUMENTATION', 'ID_COMMAND',
             'ID_CLOSE_WINDOW', 'ID_USE_SOFTTABS', 'ID_DUP_LINE', 'ID_TRANSLATE',
-            'I18N_PAGE'
+            'I18N_PAGE', 'ID_GOTO_MBRACE', 'ID_HLCARET_LINE'
 ]
 
 #---- Project Info ----#
@@ -64,6 +57,7 @@ import wx
 # GetText is not available in 2.9 but GetItemLabel is not available pre 2.8.6
 if wx.VERSION < (2, 8, 6, 0, ''):
     wx.MenuItem.GetItemLabel = wx.MenuItem.GetText
+    wx.MenuItem.GetItemLabelText = wx.MenuItem.GetLabel
 
 #---- Configuration Locations ----#
 # Values set when main loads
@@ -110,7 +104,7 @@ ID_SELECTALL     = wx.ID_SELECTALL
 ID_LINE_EDIT     = wx.NewId()
 ID_BOOKMARK      = wx.NewId()
 ID_ADD_BM        = wx.ID_ADD
-ID_DEL_BM        = wx.ID_REMOVE
+ID_DEL_BM        = wx.ID_REMOVE # Not used in menu anymore
 ID_DEL_ALL_BM    = wx.NewId()
 ID_LINE_AFTER    = wx.NewId()
 ID_LINE_BEFORE   = wx.NewId()
@@ -140,6 +134,7 @@ ID_PREF_SYNTHEME = wx.NewId()
 ID_PREF_TABS     = wx.NewId()
 ID_PREF_UNINDENT = wx.NewId()
 ID_PREF_TABW     = wx.NewId()
+ID_PREF_INDENTW  = wx.NewId()
 ID_PREF_FHIST    = wx.NewId()
 ID_PREF_WSIZE    = wx.NewId()
 ID_PREF_WPOS     = wx.NewId()
@@ -156,6 +151,7 @@ ID_SESSION       = wx.NewId()
 ID_ZOOM_OUT      = wx.ID_ZOOM_OUT
 ID_ZOOM_IN       = wx.ID_ZOOM_IN
 ID_ZOOM_NORMAL   = wx.ID_ZOOM_100
+ID_HLCARET_LINE  = wx.NewId()
 ID_SHOW_EDGE     = wx.NewId()
 ID_SHOW_EOL      = wx.NewId()
 ID_SHOW_LN       = wx.NewId()
@@ -166,6 +162,7 @@ ID_INDENT_GUIDES = wx.NewId()
 ID_VIEW_TOOL     = wx.NewId()
 ID_SHELF         = wx.NewId()
 ID_GOTO_LINE     = wx.NewId()
+ID_GOTO_MBRACE   = wx.NewId()
 ID_NEXT_MARK     = wx.ID_FORWARD
 ID_PRE_MARK      = wx.ID_BACKWARD
 
@@ -219,6 +216,7 @@ ID_TRANSLATE     = wx.NewId()
 ID_CONTACT       = wx.NewId()
 
 # Misc IDs
+ID_ADVANCED          = wx.NewId()
 ID_APP_SPLASH        = wx.NewId()
 ID_BIN_FILE          = ID_COMMAND
 ID_CDROM             = wx.NewId()
@@ -233,6 +231,7 @@ ID_FILE              = wx.ID_FILE
 ID_FLOPPY            = wx.NewId()
 ID_FOLDER            = wx.NewId()
 ID_HARDDISK          = wx.NewId()
+ID_KEY_PROFILES      = wx.NewId()
 ID_PACKAGE           = wx.NewId()
 ID_REPORTER          = wx.NewId()
 ID_STOP              = wx.ID_STOP
@@ -263,7 +262,9 @@ ID_2_PROF = {
              ID_KWHELPER          : 'KWHELPER',
              ID_EOL_MODE          : 'EOL',
              ID_PREF_FHIST        : 'FHIST_LVL',
+             ID_HLCARET_LINE      : 'HLCARETLINE',
              ID_INDENT_GUIDES     : 'GUIDES',
+             ID_KEY_PROFILES      : 'KEY_PROFILE',
              ID_PREF_LANG         : 'LANG',
              ID_REPORTER          : 'REPORTER',
              ID_SYNTAX            : 'SYNTAX',
@@ -272,6 +273,7 @@ ID_2_PROF = {
              ID_PREF_TABS         : 'USETABS',
              ID_PREF_UNINDENT     : 'BSUNINDENT',
              ID_PREF_TABW         : 'TABWIDTH',
+             ID_PREF_INDENTW      : 'INDENTWIDTH',
              ID_SESSION           : 'SAVE_SESSION',
              ID_SHOW_EDGE         : 'SHOW_EDGE',
              ID_SHOW_EOL          : 'SHOW_EOL',
