@@ -7,21 +7,17 @@
 ###############################################################################
 
 """
-FILE: ed_keyh.py
-LANGUAGE: Python
-AUTHOR: Cody Precord
+This is the Vi Emulation key handler. When vi emulation is turned on in the
+preferences, it intercepts all keypresses in the ed_stc.EditraStc and interprets
+them accordingly. In the future other key handlers may be added.
 
-SUMMARY:
- This is the Vi Emulation key handler.  When vi emulation is turned on in
-the preferences, it intercepts all keypresses in the L{ed_stc.EditraStc}
-and interprets them accordingly.  In the future other key handlers may
-be added.
+@summary: Custom keyhandler interface
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_keyh.py 52379 2008-03-08 07:08:01Z CJP $"
-__revision__ = "$Revision: 52379 $"
+__svnid__ = "$Id: ed_keyh.py 52855 2008-03-27 14:53:06Z CJP $"
+__revision__ = "$Revision: 52855 $"
 
 #-------------------------------------------------------------------------#
 # Dependencies
