@@ -7,19 +7,16 @@
 ###############################################################################
 
 """
-FILE: ed_main.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
-
-SUMMARY:
 This module provides the L{MainWindow} class for Editra. The MainWindow is
 main Ui component of the editor that contains all the other components.
 
+@summary: MainWindow Component
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_main.py 52380 2008-03-08 10:30:35Z CJP $"
-__revision__ = "$Revision: 52380 $"
+__svnid__ = "$Id: ed_main.py 53301 2008-04-22 03:37:58Z CJP $"
+__revision__ = "$Revision: 53301 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -165,6 +162,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
                                        # View Menu
                                        (ID_GOTO_LINE, self.OnCommandBar),
+                                       (ID_GOTO_MBRACE, self.DispatchToControl),
                                        (ID_VIEW_TOOL, self.OnViewTb),
 
                                        # Format Menu
@@ -217,6 +215,8 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
                                      (ID_ZOOM_NORMAL, self.OnUpdateViewUI),
                                      (ID_ZOOM_IN, self.OnUpdateViewUI),
                                      (ID_ZOOM_OUT, self.OnUpdateViewUI),
+                                     (ID_GOTO_MBRACE, self.OnUpdateViewUI),
+                                     (ID_HLCARET_LINE, self.OnUpdateViewUI),
                                      (ID_VIEW_TOOL, self.OnUpdateViewUI),
                                      (ID_SHOW_WS, self.OnUpdateViewUI),
                                      (ID_SHOW_EDGE, self.OnUpdateViewUI),
@@ -368,7 +368,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
 
     def GetNotebook(self):
         """Get the windows main notebook that contains the editing buffers
-        @return: reference to L{extern.flatnotebook.Flatnotebook} instance
+        @return: reference to L{extern.flatnotebook.FlatNotebook} instance
 
         """
         return self.nb
@@ -683,6 +683,7 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             self.Iconize(False)
 
         _PSET('WSIZE', self.GetSizeTuple())
+        _PSET('MAXIMIZED', self.IsMaximized())
         _PSET('WPOS', self.GetPositionTuple())
 
         self.LOG("[ed_main][evt] OnClose: Closing editor at pos=%s size=%s" % \
@@ -867,11 +868,12 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
         menu_ids.extend([ID_SHOW_EOL, ID_SHOW_WS, ID_INDENT_GUIDES, ID_SYNTAX,
                          ID_WORD_WRAP, ID_BRACKETHL, ID_EOL_MAC, ID_EOL_UNIX,
                          ID_EOL_WIN, ID_NEXT_MARK, ID_PRE_MARK, ID_ADD_BM,
-                         ID_DEL_BM, ID_DEL_ALL_BM, ID_FOLDING, ID_AUTOCOMP,
-                         ID_SHOW_LN,  ID_AUTOINDENT, ID_TAB_TO_SPACE,
-                         ID_SPACE_TO_TAB, ID_TRIM_WS, ID_SHOW_EDGE,
-                         ID_MACRO_START, ID_MACRO_STOP, ID_MACRO_PLAY,
-                         ID_TO_LOWER, ID_TO_UPPER, ID_KWHELPER, ID_USE_SOFTTABS
+                         ID_DEL_ALL_BM, ID_FOLDING, ID_AUTOCOMP, ID_SHOW_LN,
+                         ID_AUTOINDENT, ID_TAB_TO_SPACE, ID_SPACE_TO_TAB,
+                         ID_TRIM_WS, ID_SHOW_EDGE, ID_MACRO_START,
+                         ID_MACRO_STOP, ID_MACRO_PLAY, ID_TO_LOWER,
+                         ID_TO_UPPER, ID_KWHELPER, ID_USE_SOFTTABS,
+                         ID_GOTO_MBRACE, ID_HLCARET_LINE
                          ])
         menu_ids.extend(active_only)
 
@@ -990,6 +992,10 @@ class MainWindow(wx.Frame, viewmgr.PerspectiveManager):
             evt.Enable(zoom < 18)
         elif e_id == ID_ZOOM_OUT:
             evt.Enable(zoom > -8)
+        elif e_id == ID_GOTO_MBRACE:
+            evt.Enable(-1 not in ctrl.GetBracePair())
+        elif e_id == ID_HLCARET_LINE:
+            evt.Check(ctrl.GetCaretLineVisible())
         elif e_id == ID_VIEW_TOOL:
             evt.Check(self.GetToolBar().IsShown())
         elif e_id == ID_SHOW_WS:
