@@ -7,11 +7,6 @@
 ###############################################################################
 
 """
-FILE: ed_pages.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
-
-SUMMARY:
 This file defines the notebook for containing the text controls for
 for editing text in Editra. The note book is a custom sublclass of
 FlatNotebook that allow for automatic page images and drag and dropping
@@ -20,11 +15,13 @@ charge of opening files that are requested by the user and setting up the
 text control to use them. For more information on the text controls used
 in the notebook see ed_stc.py
 
+@summary: Editra's main notebook class
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_pages.py 52350 2008-03-06 08:28:05Z CJP $"
-__revision__ = "$Revision: 52350 $"
+__svnid__ = "$Id: ed_pages.py 53350 2008-04-25 16:50:08Z CJP $"
+__revision__ = "$Revision: 53350 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -275,11 +272,12 @@ class EdPages(FNB.FlatNotebook):
                 enc1 = ed_txt.DEFAULT_ENCODING
 
             if not self._ses_load:
+                errmap = dict(encoding1=enc1, encoding2=enc)
                 dlg = wx.MessageDialog(self,
-                                       _("The document could not be decoded with %s."
-                                         "\n\nWould you like to open it as %s instead?")
-                                       % (enc1, enc), _("Encoding Error"),
-                                       style=wx.YES_NO|wx.ICON_WARNING)
+                   _("The document could not be decoded with %(encoding1)s."
+                     "\n\nWould you like to open it as %(encoding2)s instead?")
+                   % errmap, _("Encoding Error"),
+                   style=wx.YES_NO|wx.ICON_WARNING)
                 dlg.CenterOnParent()
                 result = dlg.ShowModal()
 
@@ -655,7 +653,7 @@ class EdPages(FNB.FlatNotebook):
                 title = u"*" + title
             if title != FNB.FlatNotebook.GetPageText(self, pg_num):
                 self.SetPageText(pg_num, title)
-                ftitle = "%s - file://%s" % (title, self.control.GetFileName())
+                ftitle = u"%s - file://%s" % (title, self.control.GetFileName())
                 self.frame.SetTitle(ftitle)
         except wx.PyDeadObjectError:
             pass
@@ -717,10 +715,10 @@ def AskToReload(win, cfile):
     if result == wx.ID_YES:
         ret, rmsg = win.control.ReloadFile()
         if not ret:
+            errmap = dict(filename=cfile, errmsg=rmsg)
             mdlg = wx.MessageDialog(win.frame,
-                                    _("Failed to reload %s:\n"
-                                      "Error: %s") % \
-                                      (cfile, rmsg),
+                                    _("Failed to reload %(filename)s:\n"
+                                      "Error: %(errmsg)s") % errmsg,
                                     _("Error"),
                                     wx.OK | wx.ICON_ERROR)
             mdlg.ShowModal()
