@@ -7,23 +7,19 @@
 ###############################################################################
 
 """
-FILE: ed_stc.py
-LANGUAGE: Python
-AUTHOR: Cody Precord
+This is the main component of the editor that manages all the information
+of the on disk file that it represents in memory. It works with the StyleManager
+and SyntaxManager to provide an editing pane that auto detects and configures
+itself for type of file that is in buffer to do highlighting and other language
+specific options such as commenting code.
 
-SUMMARY:
- This is the main component of the editor that manages all the information
-of the on disk file that it represents in memory. It works with the
-L{ed_style.StyleManager} and L{syntax.syntax.SyntaxManager} to provide an
-editing pane that auto detects and configures itself for type of file that
-is in buffer to do highlighting and other language specific options such as
-commenting code.
+@summary: Editra's main text buffer class
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 52480 2008-03-14 08:01:27Z CJP $"
-__revision__ = "$Revision: 52480 $"
+__svnid__ = "$Id: ed_stc.py 53301 2008-04-22 03:37:58Z CJP $"
+__revision__ = "$Revision: 53301 $"
 
 #-------------------------------------------------------------------------#
 # Dependencies
@@ -57,9 +53,8 @@ NONSPACE = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" + \
 #-------------------------------------------------------------------------#
 class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
     """Defines a styled text control for editing text
-    @summary: Subclass of L{wx.stc.StyledTextCtrl} and
-              L{ed_style.StyleMgr}. Manages the documents display
-              and input.
+    @summary: Subclass of wx.stc.StyledTextCtrl and L{ed_style.StyleMgr}.
+              Manages the documents display and input.
 
     """
     ED_STC_MASK_MARKERS = ~wx.stc.STC_MASK_FOLDERS
@@ -135,9 +130,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.Configure()
         self.UpdateBaseStyles()
 
-        ### Folder Marker Styles
-        self.DefineMarkers()
-
         #self.Bind(wx.stc.EVT_STC_MACRORECORD, self.OnRecordMacro)
         self.Bind(wx.stc.EVT_STC_MARGINCLICK, self.OnMarginClick)
         self.Bind(wx.stc.EVT_STC_MODIFIED, self.OnModified)
@@ -259,9 +251,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         lnum = self.GetCurrentLine()
         mark = -1
         if action == ed_glob.ID_ADD_BM:
-            self.MarkerAdd(lnum, MARK_MARGIN)
-        elif action == ed_glob.ID_DEL_BM:
-            self.MarkerDelete(lnum, MARK_MARGIN)
+            if self.MarkerGet(lnum):
+                self.MarkerDelete(lnum, MARK_MARGIN)
+            else:
+                self.MarkerAdd(lnum, MARK_MARGIN)
         elif action == ed_glob.ID_DEL_ALL_BM:
             self.MarkerDeleteAll(MARK_MARGIN)
         elif action == ed_glob.ID_NEXT_MARK:
@@ -276,6 +269,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             mark = self.MarkerPrevious(lnum, 1)
             if mark == -1:
                 mark = self.MarkerPrevious(self.GetLineCount(), 1)
+
         if mark != -1:
             self.GotoLine(mark)
 
@@ -307,6 +301,36 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return [mark for mark in xrange(self.GetLineCount()) if self.MarkerGet(mark)]
 
+    def GetBracePair(self):
+        """Get a tuple of the positions in the buffer where the brace at the
+        current caret position and its match are. if a brace doesn't have a 
+        match it will return -1 for the missing brace.
+        @return: tuple (brace_at_caret, brace_opposite)
+
+        """
+        brace_at_caret = -1
+        brace_opposite = -1
+        char_before = None
+        caret_pos = self.GetCurrentPos()
+
+        if caret_pos > 0:
+            char_before = self.GetCharAt(caret_pos - 1)
+
+        # check before
+        if char_before and unichr(char_before) in "[]{}()<>":
+            brace_at_caret = caret_pos - 1
+
+        # check after
+        if brace_at_caret < 0:
+            char_after = self.GetCharAt(caret_pos)
+            if char_after and chr(char_after) in "[]{}()<>":
+                brace_at_caret = caret_pos
+
+        if brace_at_caret >= 0:
+            brace_opposite = self.BraceMatch(brace_at_caret)
+
+        return (brace_at_caret, brace_opposite)
+
     def Configure(self):
         """Configures the editors settings by using profile values
         @postcondition: all profile dependant attributes are configured
@@ -317,8 +341,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         self.SetUseAntiAliasing(_PGET('AALIASING'))
         self.SetUseTabs(_PGET('USETABS'))
         self.SetBackSpaceUnIndents(_PGET('BSUNINDENT'))
-        self.SetIndent(_PGET('TABWIDTH', 'int'))
+        self.SetCaretLineVisible(_PGET('HLCARETLINE'))
+        self.SetIndent(_PGET('INDENTWIDTH', 'int'))
         self.SetTabWidth(_PGET('TABWIDTH', 'int'))
+#        self.SetTabIndents(True) # Add option for this too?
         self.SetIndentationGuides(_PGET('GUIDES'))
         self.SetEOLFromString(_PGET('EOL'))
         self.SetViewEOL(_PGET('SHOW_EOL'))
@@ -456,6 +482,20 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         """
         return (self.GetCurrentLine() + 1, self.GetColumn(self.GetCurrentPos()))
 
+    def GotoBraceMatch(self):
+        """Jump the caret to the brace opposite of the one the caret is
+        currently at. If there is no match or the caret currently is not next
+        to a brace no action is taken.
+        @return: bool
+
+        """
+        cbrace, brace_opposite = self.GetBracePair()
+        if -1 in (cbrace, brace_opposite):
+            return False
+        else:
+            self.GotoPos(brace_opposite)
+            return True
+
     def GotoColumn(self, column):
         """Move caret to column of current line
         @param column: Column to move to
@@ -480,7 +520,10 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             line = 0
         else:
             pass
+
+        self.SetYCaretPolicy(wx.stc.STC_CARET_STRICT, 0)
         wx.stc.StyledTextCtrl.GotoLine(self, line)
+        self.SetYCaretPolicy(wx.stc.STC_CARET_EVEN, 0)
 
     def SetCurrentCol(self, column):
         """Set the current column position on the currently line
@@ -509,8 +552,18 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @postcondition: all margin markers are defined
 
         """
-        back = self.GetDefaultForeColour()
-        fore = self.GetDefaultBackColour()
+        style = self.GetItemByName('foldmargin_style')
+        # The foreground/background settings for the marker column seem to
+        # backwards from what the parameters take so use our Fore color for
+        # the stcs back and visa versa for our Back color.
+        back = style.GetFore()
+        rgb = util.HexToRGB(back[1:])
+        back = wx.Colour(red=rgb[0], green=rgb[1], blue=rgb[2])
+
+        fore = style.GetBack()
+        rgb = util.HexToRGB(fore[1:])
+        fore = wx.Colour(red=rgb[0], green=rgb[1], blue=rgb[2])
+
         self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDEROPEN,
                           wx.stc.STC_MARK_BOXMINUS, fore, back)
         self.MarkerDefine(wx.stc.STC_MARKNUM_FOLDER,
@@ -779,7 +832,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         elif len(self._code['keywords']) > 1:
             pos = self.GetCurrentPos()
             pos2 = self.WordStartPosition(pos, True)
-            print pos, pos2
             self.AutoCompShow(pos - pos2, self._code['keywords'])
         return
 
@@ -813,27 +865,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
         @type evt: wx.stc.StyledTextEvent
 
         """
-        brace_at_caret = -1
-        brace_opposite = -1
-        char_before = None
-        caret_pos = self.GetCurrentPos()
-
-        if caret_pos > 0:
-            char_before = self.GetCharAt(caret_pos - 1)
-
-        # check before
-        if char_before and chr(char_before) in "[]{}()<>":
-            brace_at_caret = caret_pos - 1
-
-        # check after
-        if brace_at_caret < 0:
-            char_after = self.GetCharAt(caret_pos)
-            if char_after and chr(char_after) in "[]{}()<>":
-                brace_at_caret = caret_pos
-
-        if brace_at_caret >= 0:
-            brace_opposite = self.BraceMatch(brace_at_caret)
-
+        brace_at_caret, brace_opposite = self.GetBracePair()
         # CallAfter necessary to reduce CG warnings on Mac
         if brace_at_caret != -1  and brace_opposite == -1:
             wx.CallAfter(self.BraceBadLight, brace_at_caret)
@@ -1008,7 +1040,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                   ed_glob.ID_TRIM_WS : self.TrimWhitespace,
                   ed_glob.ID_MACRO_START : self.StartRecord,
                   ed_glob.ID_MACRO_STOP : self.StopRecord,
-                  ed_glob.ID_MACRO_PLAY : self.PlayMacro
+                  ed_glob.ID_MACRO_PLAY : self.PlayMacro,
+                  ed_glob.ID_GOTO_MBRACE : self.GotoBraceMatch
         }
 
         e_idmap = { ed_glob.ID_ZOOM_OUT : self.DoZoom,
@@ -1022,7 +1055,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
                     ed_glob.ID_NEXT_MARK : self.Bookmark,
                     ed_glob.ID_PRE_MARK  : self.Bookmark,
                     ed_glob.ID_ADD_BM    : self.Bookmark,
-                    ed_glob.ID_DEL_BM    : self.Bookmark,
                     ed_glob.ID_DEL_ALL_BM : self.Bookmark}
 
         if self.CallTipActive():
@@ -1052,6 +1084,8 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.LinesJoin()
         elif e_id == ed_glob.ID_INDENT_GUIDES:
             self.SetIndentationGuides(not bool(self.GetIndentationGuides()))
+        elif e_id == ed_glob.ID_HLCARET_LINE:
+            self.SetCaretLineVisible(not self.GetCaretLineVisible())
         elif e_id in syntax.SyntaxIds():
             f_ext = syntax.GetExtFromId(e_id)
             self.LOG("[ed_stc][evt] Manually Setting Lexer to %s" % str(f_ext))
@@ -1854,7 +1888,7 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
 
         """
         self.StyleDefault()
-        self.SetMargins(0, 0)
+        self.SetMargins(4, 0)
         # Global default styles for all languages
         self.StyleSetSpec(0, self.GetStyleByName('default_style'))
         self.StyleSetSpec(wx.stc.STC_STYLE_DEFAULT, \
@@ -1880,14 +1914,15 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             sback = sback.GetBack()
         else:
             sback = wx.SystemSettings.GetColour(wx.SYS_COLOUR_HIGHLIGHT)
+        self.SetSelBackground(True, sback)
 
         wspace = self.GetItemByName('whitespace_style')
         if not wspace.IsNull():
             self.SetWhitespaceBackground(True, wspace.GetBack())
             self.SetWhitespaceForeground(True, wspace.GetFore())
 
-        self.SetSelBackground(True, sback)
         self.SetCaretForeground(self.GetDefaultForeColour())
+        self.SetCaretLineBack(self.GetItemByName('caret_line').GetBack())
         self.DefineMarkers()
         self.Colourise(0, -1)
 
@@ -1901,7 +1936,6 @@ class EditraStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             self.LoadStyleSheet(self.GetStyleSheet(spec_style), force=True)
         self.UpdateBaseStyles()
         self.SetSyntax(self._code['syntax_set'])
-        self.DefineMarkers()
         self.Refresh()
 
     #---- End Style Definitions ----#
