@@ -3,26 +3,21 @@
 # Purpose: Icon theme management for Editra                                   #
 # Author: Cody Precord <cprecord@editra.org>                                  #
 # Copyright: (c) 2007 Cody Precord <staff@editra.org>                         #
-# Licence: wxWindows Licence                                                  #
+# License: wxWindows License                                                  #
 ###############################################################################
 
 """
-#--------------------------------------------------------------------------#
-# FILE: ed_theme.py                                                        #
-# AUTHOR: Cody Precord                                                     #
-# LANGUAGE: Python                                                         #
-# SUMMARY:                                                                 #
-#   Provide an interface for creating icon themes for Editra. This will    #
-#  allow for themes to be created, installed, and managed as plugins,      #
-#  which means that they can be installed as single file instead of        #
-#  dozens of individual image files.                                       #
-#                                                                          #
-#--------------------------------------------------------------------------#
+Provide an interface for creating icon themes for Editra. This will allow for
+themes to be created, installed, and managed as plugins, which means that they
+can be installed as single file instead of dozens of individual image files.
+
+@summary: Editra's theme interface and implementation
+
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_theme.py 51749 2008-02-13 07:59:12Z CJP $"
-__revision__ = "$Revision: 51749 $"
+__svnid__ = "$Id: ed_theme.py 52855 2008-03-27 14:53:06Z CJP $"
+__revision__ = "$Revision: 52855 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -53,7 +48,7 @@ class ThemeI(plugin.Interface):
     def GetName(self):
         """Return the name of this theme. This is used to identify the
         theme when the provider looks for resources based on user preferences
-        
+
         @return: name string
 
         """
@@ -122,6 +117,26 @@ class BitmapProvider(plugin.Plugin):
 
         return None
 
+    def _GetTango(self, bmp_id, client):
+        """Try to get the icon from the default tango theme"""
+        theme = None
+        bmp = wx.NullBitmap
+        for prov in self.observers:
+            if prov.GetName() == TangoTheme.name:
+                theme = prov
+                break
+        else:
+            return bmp
+
+        if client == wx.ART_TOOLBAR:
+            bmp = theme.GetToolbarBitmap(bmp_id)
+        elif client == wx.ART_MENU:
+            bmp = theme.GetMenuBitmap(bmp_id)
+        else:
+            pass
+
+        return bmp
+
     def GetThemes(self):
         """Gets a list of the installed and activated themes
         @return: list of strings
@@ -135,7 +150,7 @@ class BitmapProvider(plugin.Plugin):
         found.
 
         @param bmp_id: id of bitmap to lookup
-        @param client: wxART_MENU, ART_MIME, wxART_TOOLBAR
+        @param client: wxART_MENU, wxART_TOOLBAR
         @see: L{ed_glob}
 
         """
@@ -148,12 +163,19 @@ class BitmapProvider(plugin.Plugin):
 
             if bmp.IsOk():
                 return bmp
+
+        # Try to fallback to tango theme when icon lookup fails
+        bmp = self._GetTango(bmp_id, client)
+        if bmp.IsOk():
+            return bmp
+
         return wx.NullBitmap
 
 #-----------------------------------------------------------------------------#
 # Default theme data maps
 ART = { ed_glob.ID_ABOUT  : u'about.png',
         ed_glob.ID_ADD_BM : u'bmark_add.png',
+        ed_glob.ID_ADVANCED : u'advanced.png',
         ed_glob.ID_BIN_FILE : u'bin_file.png',
         ed_glob.ID_CDROM  : u'cdrom.png',
         ed_glob.ID_CONTACT : u'mail.png',
@@ -239,6 +261,8 @@ class TangoTheme(plugin.Plugin):
     """Represents the Tango Icon theme for Editra"""
     plugin.Implements(ThemeI)
 
+    name = u'Tango'
+
     def __GetArtPath(self, client, mime=False):
         """Gets the path of the resource directory to get
         the bitmaps from.
@@ -258,7 +282,7 @@ class TangoTheme(plugin.Plugin):
                                 Profile_Get('ICONS'), u'mime')
         else:
             path = os.path.join(ed_glob.CONFIG['THEME_DIR'],
-                                Profile_Get('ICONS'),
+                                self.GetName(),
                                 clients.get(client, u"menu"))
 
         path += os.sep
@@ -273,7 +297,7 @@ class TangoTheme(plugin.Plugin):
         @return: string
 
         """
-        return u'Tango'
+        return TangoTheme.name
 
     def GetMenuBitmap(self, bmp_id):
         """Get a menu bitmap
