@@ -7,23 +7,20 @@
 ###############################################################################
 
 """
-FILE: iface.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
-SUMMARY:
-  This module contains numerous plugin interfaces and the Extension points
-that they extend. Included below is a list of interfaces available in this
-module.
+This module contains numerous plugin interfaces and the Extension points that
+they extend. Included below is a list of interfaces available in this module.
 
 Intefaces:
-  * ShelfI: Interface into the L{Shelf}
-  * MainWindowI: Interface into L{ed_main.MainWindow}
+  - ShelfI: Interface into the L{Shelf}
+  - MainWindowI: Interface into L{ed_main.MainWindow}
+
+@summary: Main Plugin interface defintions
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: iface.py 51989 2008-02-22 10:19:20Z CJP $"
-__revision__ = "$Revision: 51989 $"
+__svnid__ = "$Id: iface.py 52855 2008-03-27 14:53:06Z CJP $"
+__revision__ = "$Revision: 52855 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
