@@ -7,24 +7,21 @@
 ###############################################################################
 
 """
- FILE: profiler.py
- AUTHOR: Cody Precord
- LANGUAGE: Python
+This module provides the profile object and support functions for loading and
+saving user preferences between sessions. The preferences are saved on disk as
+a cPickle, because of this no objects that cannot be resolved in the namespace
+of this module prior to starting the mainloop must not be put in the Profile as
+it will cause errors on load. Ths means that only builtin python types should
+be used and that a translation from that type to the required type should
+happen during run time.
 
- @summary:
-   This module provides the profile object and support functions for
- loading and saving user preferences between sessions. The preferences are
- saved on disk as a cPickle, because of this no objects that cannot be
- resolved in the namespace of this module prior to starting the mainloop
- must not be put in the Profile as it will cause errors on load. Ths means
- that only builtin python types should be used and that a translation from
- that type to the required type should happen during run time.
+@summary: Editra's user profile management
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: profiler.py 52188 2008-02-29 06:19:49Z CJP $"
-__revision__ = "$Revision: 52188 $"
+__svnid__ = "$Id: profiler.py 53301 2008-04-22 03:37:58Z CJP $"
+__revision__ = "$Revision: 53301 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -59,10 +56,14 @@ _DEFAULTS = {
            'FHIST_LVL'  : 9,                # Filehistory length (9 is max)
            'FFILTER'    : 0,                # Last file filter used
            'GUIDES'     : False,            # Use Indentation guides
+           'HLCARETLINE': False,            # Highlight Caret Line
            'ICONS'      : 'Tango',          # Icon Theme
            'ICON_SZ'    : (24, 24),         # Toolbar Icon Size
+           'INDENTWIDTH': 4,                # Default indent width
+           'KEY_PROFILE': None,             # Keybinding profile
            'LANG'       : 'Default',        # UI language
            'LASTCHECK'  : 0,                # Last time update check was done
+           'MAXIMIZED'  : False,            # Was window maximized on exit
            'MODE'       : 'CODE',           # Overall editor mode
            'MYPROFILE'  : 'default.ppb',    # Path to profile file
            'OPEN_NW'    : False,            # Open files in new windows
