@@ -7,20 +7,18 @@
 ###############################################################################
 
 """
-FILE: style_editor.py
-AUTHOR: Cody Precord
-LANGUAGE: Python
-SUMMARY:
-  Provides an editor dialog for graphically editing how the text is
-presented in the editor when syntax highlighting is turned on. It does
-this by taking the data from the controls and formating it into an Editra
-Style Sheet that the editor can load to configure the styles of the text.
+Provides an editor dialog for graphically editing how the text is presented in 
+the editor when syntax highlighting is turned on. It does this by taking the 
+data from the controls and formating it into an Editra Style Sheet that the 
+editor can load to configure the styles of the text.
+
+@summary: Gui for creating custom Editra Style Sheets
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: style_editor.py 51748 2008-02-13 07:57:18Z CJP $"
-__revision__ = "$Revision: 51748 $"
+__svnid__ = "$Id: style_editor.py 53301 2008-04-22 03:37:58Z CJP $"
+__revision__ = "$Revision: 53301 $"
 
 #--------------------------------------------------------------------------#
 # Dependancies
@@ -74,6 +72,7 @@ class StyleEditor(wx.Dialog):
         self.preview = ed_stc.EditraStc(self, wx.ID_ANY, size=(-1, 200),
                                         style=wx.SUNKEN_BORDER, use_dt=False)
         self.styles_orig = self.preview.GetStyleSet()
+        self.preview.SetCaretLineVisible(True)
         self.styles_new = DuplicateStyleDict(self.styles_orig)
         self.preview.SetStyles('preview', self.styles_new, True)
         self.OpenPreviewFile('cpp')
@@ -494,6 +493,7 @@ class StyleEditor(wx.Dialog):
 
         """
         fname = file_lbl.replace(u" ", u"_").replace(u"/", u"_").lower()
+        fname = fname.replace('#', 'sharp')
         try:
             fname = glob.glob(ed_glob.CONFIG['TEST_DIR'] + fname + ".*")[0]
         except IndexError:
